@@ -75,7 +75,7 @@ if (gui == TRUE) {
       } else {
         cat("\n")
         cat("GUI could not be launched -- default settings will be used;\n")
-        cat("otherwise please pass your variables as command-line agruments\n")
+        cat("otherwise please pass your variables as command-line agruments\n\n")
       }
 }
 
@@ -236,68 +236,6 @@ if(number.of.candidates < 1) {
 
 
 
-# #################################################
-# FUNCTIONS:
-
-
-
-
-
-
-
-# #################################################
-# Function for preparing and printing
-# the final ranking of the least unlikely authors
-# for each text in a given table of distances.
-# Arguments: 1. table with distances, 2. number of candidates to be displayed
-# #################################################
-
-# what about getting back to this old version in which ALL candidates
-# were listed, instead of listing only those misclassified?
-# it can be done as an option
-
-make.ranking.of.candidates = function(dist.matrix,candidates) {
-  for(h in 1:length(dist.matrix[,1])) {
-  ranked.candidates = order(dist.matrix[h,])
-  current.sample = c(gsub("_.*","",colnames(dist.matrix)))[ranked.candidates]
-    if((gsub("_.*","",rownames(dist.matrix)))[h] != current.sample[1]) {
-  	cat(c(c(rownames(dist.matrix))[h]," ", "-->", " ", 
-      current.sample[1:candidates], " (delta score:", 
-      round(dist.matrix[h,ranked.candidates[1:candidates]],4), ")",
-      "\n"),file=outputfile,append=T)
-    }
-  }
-}
-
-
-
-# #################################################
-# Function for preparing and printing
-# the number of correct attributions
-# this is a variant of the above function make.ranking.of.candidates
-# Argument: table of distances
-# #################################################
-
-make.number.of.correct.attributions = function(dist.matrix) {
-  corr.attrib = 0
-  for(h in 1:length(dist.matrix[,1])) {
-  ranked.c = order(dist.matrix[h,])
-  current.sample = c(gsub("_.*","",colnames(dist.matrix)))[ranked.c]
-    if((gsub("_.*","",rownames(dist.matrix)))[h] == current.sample[1]) {
-    corr.attrib = corr.attrib + 1
-    }
-  }
-# the result of the function:
-return(corr.attrib)
-}
-
-# #############################################################################
-
-
-
-
-
-
 
 
 
@@ -584,7 +522,7 @@ if(corpus.exists == FALSE) {
 
   # Checking whether required files and subdirectories exist
   if(file.exists(training.corpus.dir) == FALSE | file.exists(test.corpus.dir) == FALSE) {
-    cat("\n\n !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n",
+    cat("\n\n!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n",
         "Working directory should contain two subdirectories: 
         \"",training.corpus.dir,"\" and \"",test.corpus.dir,"\"\n",
         "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n\n",sep="")
@@ -595,7 +533,7 @@ if(corpus.exists == FALSE) {
   }
   # Checking if the subdirectories contain any stuff
   if(length(filenames.primary.set) <2 | length(filenames.secondary.set) <2) {
-    cat("\n\n !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n",
+    cat("\n\n!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n",
         "Both subdirectories \"",training.corpus.dir,"\" and \"",
         test.corpus.dir,"\" should contain at least two text samples!\n",
         "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n\n",sep="")
@@ -971,7 +909,8 @@ for(j in (culling.min/culling.incr):(culling.max/culling.incr)) {
         # of joint primary and secondary sets
         if(culling.of.all.samples == FALSE) {
                 # applying the function culling to the I set
-                primary.set = culling(freq.I.set.0.culling, current.culling)
+                primary.set = perform.culling(freq.I.set.0.culling,  
+                                             current.culling)
                 # selecting the same variables from the II set
                 secondary.set = freq.II.set.0.culling[,colnames(primary.set)]
         } else {
@@ -979,8 +918,8 @@ for(j in (culling.min/culling.incr):(culling.max/culling.incr)) {
                 freq.table.both.sets = rbind(freq.I.set.0.culling, 
                                              freq.II.set.0.culling)
                 # applying the culling function to the combined table
-                freq.table.both.sets = culling(freq.table.both.sets, 
-                                               current.culling)
+                freq.table.both.sets = perform.culling(freq.table.both.sets, 
+                                             current.culling)
                 # split the combined table into two sets again
                 primary.set = freq.table.both.sets[rownames(freq.I.set.0.culling),]
                 secondary.set = freq.table.both.sets[rownames(freq.II.set.0.culling),]
@@ -1052,17 +991,7 @@ cat("culling @ ", current.culling,"\t","available words ",
 
 
 
-# #################################################
-# z-scores calcutations
-# #################################################
-
-
-# mean and standard dev. for each word (in primary set)
-primary.set.mean = c(sapply(as.data.frame(primary.set), mean))
-primary.set.sd = c(sapply(as.data.frame(primary.set), sd))
-
-# calculating z-scores for both I and II sets (a message on the screen)
-cat("Calculating z-scores... \n\n")
+                  
 
 
 # an additional table composed of relative word frequencies 
@@ -1074,31 +1003,36 @@ freq.table.both.sets = rbind(primary.set, secondary.set)
 # Entropy distance: experimental, but entirely available
 # (the results do not really differ than for typical word frequencies)
 #
-#A = t(t(freq.table.both.sets + 1) / colSums(freq.table.both.sets + 1))
-#B =t(t(log(freq.table.both.sets + 2)) / -(colSums(A * log(A))))
-#freq.table.both.sets = B
+# A = t(t(freq.table.both.sets + 1) / colSums(freq.table.both.sets + 1))
+# B = t(t(log(freq.table.both.sets + 2)) / -(colSums(A * log(A))))
+# freq.table.both.sets = B
 #
 
 
-
-# calculating z-scores either of primary set, or of both sets
-if(z.scores.of.all.samples == FALSE) {
-  # function for z-scores scaling executed for primary.set
-  zscores.primary.set = scale(primary.set)
-  rownames(zscores.primary.set) = rownames(primary.set)
-  # function for z-scores scaling executed for secondary.set
-  zscores.secondary.set = 
-            scale(secondary.set, center=primary.set.mean, scale=primary.set.sd)
-  rownames(zscores.secondary.set) = rownames(secondary.set)
-  # the two tables with calculated z-scores should be put together
-  zscores.table.both.sets = rbind(zscores.primary.set, zscores.secondary.set)
-} else {
-  # the z-scores can be calculated on both sets as alternatively  
-  zscores.table.both.sets = scale(freq.table.both.sets)
-  zscores.table.both.sets = zscores.table.both.sets[,]
-  zscores.primary.set = zscores.table.both.sets[1:length(primary.set[,1]),]
-  zscores.secondary.set = zscores.table.both.sets[1:length(secondary.set[,1]),]
-  }
+if(tolower(classification.method) == "delta") {
+        # a short message on the screen:
+        if(distance.measure == "CD") {
+                cat("Calculating classic Delta distances... \n")
+        }
+        if(distance.measure == "AL") {
+                cat("Calculating Argamon's Delta distances... \n")
+        }
+        if(distance.measure == "ED") {
+                cat("Calculating Eder's Delta distances... \n")
+        }
+        if(distance.measure == "ES") {
+                cat("Calculating Eder's Simple distances... \n")
+        }
+        if(distance.measure == "MH") {
+                cat("Calculating Mahattan distances... \n")
+        }
+        if(distance.measure == "CB") {
+                cat("Calculating Canberra distances... \n")
+        }
+        if(distance.measure == "EU") {
+                cat("Calculating Euclidean distances... \n")
+        }
+}
 
 
 
@@ -1113,31 +1047,6 @@ if(z.scores.of.all.samples == FALSE) {
 # the internal loop starts here (for i = mfw.min : mfw.max)
 # #################################################
 
-# a short message on the screen:
-if(distance.measure == "CD") {
-  cat("Calculating classic Delta distances... \n")
-  }
-if(distance.measure == "AL") {
-  cat("Calculating Argamon's Delta distances... \n")
-  }
-if(distance.measure == "ED") {
-  cat("Calculating Eder's Delta distances... \n")
-  }
-if(distance.measure == "ES") {
-  cat("Calculating Eder's Simple distances... \n")
-  }
-if(distance.measure == "MH") {
-  cat("Calculating Mahattan distances... \n")
-  }
-if(distance.measure == "CB") {
-  cat("Calculating Canberra distances... \n")
-  }
-if(distance.measure == "EU") {
-  cat("Calculating Euclidean distances... \n")
-  }
-
-
-
 
 
 for(i in seq(mfw.min, mfw.max, round(mfw.incr)) ) {
@@ -1161,8 +1070,6 @@ cat(mfw, " ")
 
 
 
-# FOR SOME REASON, IT IS NEEDED AT SOME POINT, even if this is obsolete
-distance.name.on.graph = "standard classification"
 
 
 
@@ -1172,187 +1079,14 @@ distance.name.on.graph = "standard classification"
 
 
 
-# Delta in its various flavours
-
-perform.delta = function(training.set, test.set, distance.measure = "CD") {
-
-  
-# first, combining the two sets into one matrix        
-zscores.table.both.sets = rbind(training.set, test.set)
-
-        
-# calculating classic Delta distances
-if(distance.measure == "CD") {
-  distance.name.on.graph = "Classic Delta distance"
-  distance.name.on.file = "Classic Delta"
-  distance.table = 
-            as.matrix(dist(zscores.table.both.sets[,1:mfw],
-            method="manhattan")) / mfw
-  }
-# calculating Argamon's "Linear Delta"
-if(distance.measure == "AL") {
-  distance.name.on.graph = "Argamon's Delta distance"
-  distance.name.on.file = "Argamon's Delta"
-  distance.table = 
-            as.matrix(dist(zscores.table.both.sets[,1:mfw],
-            method="euclidean")) / mfw
-  }
-# calculating Delta distances with Eder's modifications
-if(distance.measure == "ED") {
-  distance.name.on.graph = "Eder's Delta distance"
-  distance.name.on.file = "Eder's Delta"
-  zscores.plus.e.value = t(t(zscores.table.both.sets[,1:mfw])*((1+mfw:1)/mfw))
-  distance.table = as.matrix(dist(zscores.plus.e.value,method="manhattan"))
-  }
-# calculating Eder's Simple distance to a matrix distance.table
-if(distance.measure == "ES") {
-  distance.table = 
-         as.matrix(dist(sqrt(freq.table.both.sets[,1:mfw]),method="manhattan"))
-  distance.name.on.graph = "Eder's Simple distance"
-  distance.name.on.file = "Eder's Simple"
-  }
-# calculating Manhattan distance to a matrix distance.table
-if(distance.measure == "MH") {
-  distance.name.on.graph = "Manhattan distance"
-  distance.name.on.file = "Manhattan"
-  distance.table = 
-           as.matrix(dist(freq.table.both.sets[,1:mfw],method="manhattan"))
-  }
-# calculating Canberra distance to a matrix distance.table
-if(distance.measure == "CB") {
-  distance.name.on.graph = "Canberra distance"
-  distance.name.on.file = "Canberra"
-  distance.table = 
-           as.matrix(dist(freq.table.both.sets[,1:mfw],method="canberra"))
-  }
-# calculating Euclidean distance to a matrix distance.table
-if(distance.measure == "EU") {
-  distance.name.on.graph = "Euclidean distance"
-  distance.name.on.file = "Euclidean"
-  distance.table = 
-           as.matrix(dist(freq.table.both.sets[,1:mfw],method="euclid"))
-  }
-# replaces the names of the samples (the extension ".txt" is cut off)
-rownames(distance.table)=gsub("\\.txt$","",rownames(zscores.table.both.sets))
-colnames(distance.table)=gsub("\\.txt$","",rownames(zscores.table.both.sets))
-
-# #################################################
-# extracting candidates, drawing, printing, etc.
-
-# a selected area of the distance.table is needed, with colnames()
-no.of.possib = length(training.set[,1])
-no.of.candid = length(test.set[,1])
-selected.dist = 
-          as.matrix(distance.table[no.of.possib+1:no.of.candid,1:no.of.possib])
-
-return(selected.dist)
-}
-
-
-
-
-perform.knn = function(training.set, test.set, k.value=1) {
-  #kNN classification:
-  # library(class)
-  #
-  # training_set and test_set preparation; adding class labels to both sets
-  classes.training = gsub("_.*","",rownames(training.set))
-  classes.test = gsub("_.*","",rownames(test.set))
-  training.set = cbind(classes.training,training.set)
-  test.set = cbind(classes.test,test.set)
-  #
-  # classes that will be used for training the classifier (=classes of I set)
-  classes = factor(training.set[,1])
-  # training and classification
-  classification.results = knn(training.set[,-1],test.set[,-1],classes,k=k.value)
-  # cross-validation: 
-  #knn.cv(training.set[,-1],classes,k=k.value,prob=T)
-  # get final results
-  classification.results = as.character(classification.results)
-return(classification.results)
-}
-
-
-perform.naivebayes = function(training.set, test.set) {
-  # Naive Bayes classification:
-  #  library(e1071)
-  #
-  # training_set and test_set preparation; adding class labels to both sets
-  classes.training = gsub("_.*","",rownames(training.set))
-  classes.test = gsub("_.*","",rownames(test.set))
-  classes = c(classes.training, classes.test)
-  input.data = as.data.frame(rbind(training.set,test.set))
-  input.data = cbind(classes, input.data)
-  training.classes = c(1:length(training.set[,1]))
-  #
-  # training a model
-  model = naiveBayes(classes ~ ., data = input.data, subset = training.classes)
-  #
-  # testing the model on "new" data (i.e. the test.set)
-  classification.results = predict(model, input.data[,-1])
-  classification.results = as.character(classification.results)
-  classification.results = classification.results[-c(1:length(classes.training))]
-return(classification.results)
-}
-
-
-
-perform.svm = function(training.set, test.set) {
-  # Support Vector Machines classification:
-  # library(e1071)
-  #
-  # training_set and test_set preparation; adding class labels to both sets
-  classes.training = gsub("_.*","",rownames(training.set))
-  classes.test = gsub("_.*","",rownames(test.set))
-  classes = c(classes.training, classes.test)
-  input.data = as.data.frame(rbind(training.set,test.set))
-  input.data = cbind(classes, input.data)
-  training.classes = c(1:length(training.set[,1]))
-  #
-  # training a model
-#  model = svm(classes ~ ., data = input.data, subset = training.classes)
-  model = svm(classes ~ ., data = input.data, subset = training.classes, 
-                 kernel = svm.kernel, degree = svm.degree, coef0 = svm.coef0, 
-                 cost = svm.cost)
-  #
-  # testing the model on "new" data (i.e. the test.set)
-  classification.results = predict(model, input.data[,-1])
-  classification.results = as.character(classification.results)
-  classification.results = classification.results[-c(1:length(classes.training))]
-  #plot(cmdscale(dist(input.data[,-1])),col=as.integer(input.data[,1]),pch=c("o","+"))
-return(classification.results)
-}
 
 
 
 
 
 
-perform.nsc = function(training.set, test.set) {
-# Nearest Shrunken Centroid classification:
-  #  library(pamr)
-  #
-  # training_set and test_set preparation; adding class labels to both sets
-  classes.training = gsub("_.*","",rownames(training.set))
-  classes.test = gsub("_.*","",rownames(test.set))
-  classes = c(classes.training, classes.test)
-  input.data = as.data.frame(rbind(training.set,test.set))
-  training.classes = c(1:length(training.set[,1]))
-  mydata=list(x = t(input.data),
-              y = as.factor(classes),
-              geneid = as.character(1:length(colnames(training.set))), 
-              genenames = colnames(training.set)
-              )
-  # training a model
-  model = pamr.train(mydata,sample.subset=c(1:length(classes.training)))
-# getting the most discriminative features
-#  the.features = pamr.listgenes(model,mydata,threshold=5,genenames=TRUE)[,2]
-  # testing the model on "new" data (i.e. the test.set)
-  classification.results = pamr.predict(model,mydata$x,threshold=1)
-  classification.results = as.character(classification.results)
-  classification.results = classification.results[-c(1:length(classes.training))]
-return(classification.results)
-}
+
+
 
 
 
@@ -1361,8 +1095,14 @@ return(classification.results)
 
 
 if(tolower(classification.method) == "delta") {
-  selected.dist = perform.delta(zscores.primary.set, zscores.secondary.set, 
-                                distance.measure)
+  classification.results = perform.delta(training.set = primary.set[,1:mfw], 
+                                test.set = secondary.set[,1:mfw],
+                                distance = distance.measure,
+                                z.scores.both.sets = z.scores.of.all.samples)
+#
+# this should be provided by the function perform.delta (value: list of objects)
+#distance.table = "sorry! temporarily out of order"
+#
 }
 
 
@@ -1402,16 +1142,13 @@ classes.test = gsub("_.*","",rownames(secondary.set))
 # returns the ranking of the most likely candidates as a list
 if(final.ranking.of.candidates == TRUE) {
     cat("\n\n\n",file=outputfile,append=T)
-    if(tolower(classification.method) == "delta") {
-      make.ranking.of.candidates(selected.dist,number.of.candidates)
-    } else {
       misclassified.samples = 
                    paste(rownames(secondary.set), "\t-->\t",
                    classification.results)[classes.test!=classification.results]
       cat(misclassified.samples, file=outputfile, append=T, sep="\n") 
-      # temporarily (the results should be maed available, eventually)
+      # temporarily (the results should be made available, eventually)
       rm(misclassified.samples)
-    }
+#    }
 }
 
 
@@ -1419,12 +1156,8 @@ if(final.ranking.of.candidates == TRUE) {
 
 # returns the number of correct attributions
 if(how.many.correct.attributions == TRUE) {
-    if(tolower(classification.method) == "delta") {
-      no.of.correct.attrib = make.number.of.correct.attributions(selected.dist)
-    } else {
-      no.of.correct.attrib = sum(as.numeric(classes.test == 
+    no.of.correct.attrib = sum(as.numeric(classes.test == 
                                  classification.results))
-    }
     total.no.of.correct.attrib = 
          c(total.no.of.correct.attrib, no.of.correct.attrib)
     total.no.of.possible.attrib = 
@@ -1517,16 +1250,15 @@ if(cv.folds > 0) {
   test.set = freq.table.both.sets.binded[test.samples,]
 
   
-  zscores.training.set = zscores.table.both.sets[training.samples,]
-  zscores.test.set = zscores.table.both.sets[test.samples,]
+ # zscores.training.set = zscores.table.both.sets[training.samples,]
+ # zscores.test.set = zscores.table.both.sets[test.samples,]
     
 
   if(tolower(classification.method) == "delta") {
-    # zscores as a separate function should be applied here:
-#    current.zscores = scale(freq.table.both.sets.binded)
-    selected.dist1 = perform.delta(zscores.training.set,
-                                   zscores.test.set, 
-                                   distance.measure)
+    classification.results = perform.delta(training.set,
+                                   test.set, 
+                                   distance = distance.measure,
+                                   z.scores.both.sets = z.scores.of.all.samples)
   }
   if(tolower(classification.method) == "knn") {
     classification.results = perform.knn(training.set,test.set, k.value)
@@ -1552,13 +1284,8 @@ if(cv.folds > 0) {
   
     # returns the number of correct attributions
     if(how.many.correct.attributions == TRUE) {
-        if(tolower(classification.method) == "delta") {
-          no.of.correct.attrib = make.number.of.correct.attributions(selected.dist1)
-        } else {
           no.of.correct.attrib = sum(as.numeric(classes.test == 
                                      classification.results))
-        }
-      # 
       # getting the max. number of samples that couold be guessed
       perfect.guessing.cv = sum(as.numeric(classes.test %in% classes.training))
       cat("\n",file=outputfile,append=T)
@@ -1670,8 +1397,8 @@ cat("\nGeneral attributive success:  ", total.no.of.correct.attrib, " of ",
 cat("\nMFWs from ",mfw.min," to ",mfw.max.original,
                   " @ increment ",mfw.incr,"\nCulling from ",culling.min,
                   " to ",culling.max," @ increment ",culling.incr,
-                  "\nPronouns deleted: ",delete.pronouns,"; ",
-                  distance.name.on.graph,"\n",file=outputfile,append=T,sep="")
+                  "\nPronouns deleted: ",delete.pronouns,"\n",
+				  file=outputfile,append=T,sep="")
 # additional empty line in outputfile (EOF)
 cat("\n",file=outputfile,append=T)
 
@@ -1684,8 +1411,7 @@ cat("\nGeneral attributive success:  ", total.no.of.correct.attrib, " of ",
 cat("\nMFWs from ",mfw.min," to ",mfw.max.original,
                   " @ increment ",mfw.incr,"\nCulling from ",culling.min,
                   " to ",culling.max," @ increment ",culling.incr,
-                  "\nPronouns deleted: ",delete.pronouns,"; ",
-                  distance.name.on.graph,"\n",sep="")
+                  "\nPronouns deleted: ",delete.pronouns,"\n",sep="")
 cat("\n")
 
 
@@ -1706,7 +1432,7 @@ success.rate = all.guesses
 frequencies.training.set = freq.I.set.0.culling
 frequencies.test.set = freq.II.set.0.culling
 frequencies.both.sets = freq.table.both.sets
-zscores.both.sets = zscores.table.both.sets
+#zscores.both.sets = zscores.table.both.sets
 features.actually.used = colnames(freq.table.both.sets[,1:mfw])
 features = mfw.list.of.all
 
@@ -1731,7 +1457,9 @@ if(exists("misclassified.samples")) {
 }
 if(exists("cross.validation.summary") & length(cross.validation.summary) >0 ) {
   attr(cross.validation.summary, "description") = "correctly guessed samples (cross-validation folds)"
-  class(cross.validation.summary) = c("stylo.data", "matrix")
+  if(dim(as.matrix(cross.validation.summary))[2] >1) {
+    class(cross.validation.summary) = c("stylo.data", "matrix")
+  }
 }
 if(exists("success.rate")) {
   attr(success.rate, "description") = "percentage of correctly guessed samples"
